Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(601)

Unified Diff: ui/aura/window_event_dispatcher.h

Issue 754013007: Fix the wrong relative coordinates from EventDispatch (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ui/aura/window_event_dispatcher.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/aura/window_event_dispatcher.h
diff --git a/ui/aura/window_event_dispatcher.h b/ui/aura/window_event_dispatcher.h
index d2ea8a9ec6bbaa4021e7fa4b4802089ee91c4336..b06011b87b2cca19c39ec26f0d853a115e4f9b2e 100644
--- a/ui/aura/window_event_dispatcher.h
+++ b/ui/aura/window_event_dispatcher.h
@@ -76,10 +76,12 @@ class AURA_EXPORT WindowEventDispatcher : public ui::EventProcessor,
void DispatchCancelModeEvent();
// Dispatches a ui::ET_MOUSE_EXITED event at |point|.
// TODO(beng): needed only for WTH::OnCursorVisibilityChanged().
- ui::EventDispatchDetails DispatchMouseExitAtPoint(
- const gfx::Point& point) WARN_UNUSED_RESULT;
+ ui::EventDispatchDetails DispatchMouseExitAtPoint(Window* target,
+ const gfx::Point& point)
+ WARN_UNUSED_RESULT;
// Gesture Recognition -------------------------------------------------------
@@ -151,9 +153,12 @@ class AURA_EXPORT WindowEventDispatcher : public ui::EventProcessor,
// Dispatches the specified event type (intended for enter/exit) to the
// |mouse_moved_handler_|.
- ui::EventDispatchDetails DispatchMouseEnterOrExit(
- const ui::MouseEvent& event,
- ui::EventType type) WARN_UNUSED_RESULT;
+ // The event's location will be converted from |target|coordinate system to
+ // |mouse_moved_handler_| coordinate system.
+ ui::EventDispatchDetails DispatchMouseEnterOrExit(Window* target,
+ const ui::MouseEvent& event,
+ ui::EventType type)
+ WARN_UNUSED_RESULT;
ui::EventDispatchDetails ProcessGestures(
ui::GestureRecognizer::Gestures* gestures) WARN_UNUSED_RESULT;
« no previous file with comments | « no previous file | ui/aura/window_event_dispatcher.cc » ('j') | no next file with comments »
@@ -76,10 +76,12 @@ class AURA_EXPORT WindowEventDispatcher : public ui::EventProcessor,
void DispatchCancelModeEvent();
- // Dispatches a ui::ET_MOUSE_EXITED event at |point|.
+ // Dispatches a ui::ET_MOUSE_EXITED event at |point| to the |target|
+ // If the |target| is NULL, we will dispatch the event to the root-window
// TODO(beng): needed only for WTH::OnCursorVisibilityChanged().

Powered by Google App Engine
This is Rietveld 408576698